@@ -14,6 +14,7 @@ class EvaluateFactor(object):
     
     def __init__(self,
                  df: "pd.DataFrame",
+                 proposed_factor,
                  current_sort_by_var,
                  proposed_sort_by_var,
                  group_by_var,
@@ -43,6 +44,7 @@ class EvaluateFactor(object):
         """
 
         self.df = df
+        self.proposed_factor = proposed_factor
         self.current_sort_by_var = current_sort_by_var
         self.proposed_sort_by_var = proposed_sort_by_var
         self.group_by_var = group_by_var
@@ -229,27 +231,27 @@ class EvaluateFactor(object):
     def compare_loss_table(self):
     
         df = self.df
-        proposed_variable = self.proposed_sort_by_var
+        proposed_variable = self.proposed_factor
     
-        variable = df[proprosed_variable].unique()
+        variable = df[proposed_variable].unique()
         variable = variable.tolist()
         variable.sort()
-        count = df.groupby([proprosed_variable])["policy_number"].count()
-        claim = df.groupby([proprosed_variable])["claim_indicator"].sum()
+        count = df.groupby([proposed_variable])["policy_number"].count()
+        claim = df.groupby([proposed_variable])["claim_indicator"].sum()
         freq = claim/count
 
-        il = df.groupby([proprosed_variable])["il"].sum()
-        curr_ep = df.groupby([proprosed_variable])["curr_earned_premium"].sum()
-        prop_ep = df.groupby([proprosed_variable])["prop_earned_premium"].sum()
+        il = df.groupby([proposed_variable])["il"].sum()
+        curr_ep = df.groupby([proposed_variable])["curr_earned_premium"].sum()
+        prop_ep = df.groupby([proposed_variable])["prop_earned_premium"].sum()
         curr_lr = il/curr_ep
         prop_lr = il/prop_ep
 
-        titles = [proprosed_variable, 'Policy Count', '# of Claims', 'Freq.', 'Current LR', 'Proposed LR']
+        titles = [proposed_variable, 'Policy Count', '# of Claims', 'Freq.', 'Current LR', 'Proposed LR']
         rows = list(zip(variable, count, claim, freq, curr_lr, prop_lr))
 
         return print(tabulate(rows, headers=titles, floatfmt=".4f"))
     
-    def overall_impact(df):
+    def overall_impact(self):
 
         df = self.df
         
